ArticleBasketRawAbstract class abstract

Inheritance
Implementers

Constructors

ArticleBasketRawAbstract({required int calibreId, required int id, required String designation, required List<ProxyArticle> proxies, bool status = true, ArticleKind kind = ArticleKind.basket})
const

Properties

calibreId → int
finalinherited
designation → String
finalinherited
hashCode → int
The hash code for this object.
no setteroverride
id → int
finalinherited
kind → ArticleKind
finalinherited
proxies → List<ProxyArticle>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → bool
finalinherited

Methods

nameWithoutArtCalibrePart(String calibreTitle) → String
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
override
toMap() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override