ArticlePhotoAbstract class abstract

Inheritance
Implementers

Constructors

ArticlePhotoAbstract({required int calibreId, required int id, DateTime? dateUTC, required String path, required PhotoSource source})
const

Properties

calibreId → int
final
dateUTC → DateTime?
will be compared against a date in UTC for server, simpler to store is as UTC
final
hashCode → int
The hash code for this object.
no setteroverride
id → int
final
path → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → PhotoSource
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override