ArticleRawAbstract class abstract

Implementers

Constructors

ArticleRawAbstract({required int calibreId, required int id, required String designation, ArticleKind kind = ArticleKind.unknown, bool status = true})
const

Properties

calibreId → int
final
designation → String
final
hashCode → int
The hash code for this object.
no setteroverride
id → int
final
kind → ArticleKind
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → bool
final

Methods

nameWithoutArtCalibrePart(String calibreTitle) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override