ArticleRetailRawAbstract class abstract

Inheritance
Implementers

Constructors

ArticleRetailRawAbstract({required int calibreId, required int id, required String designation, ArticleKind kind = ArticleKind.retail, bool status = true, required num price, required num cost, double unitsInOnePiece = 1.0})
const

Properties

calibreId → int
finalinherited
cost → num
final
costClean → num
no setter
designation → String
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
id → int
finalinherited
kind → ArticleKind
finalinherited
price → num
final
priceClean → num
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → bool
finalinherited
unitsInOnePiece → double
final

Methods

nameWithoutArtCalibrePart(String calibreTitle) → String
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
override
toMap() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited