BoutiqueAbstract class abstract

Implementers

Constructors

BoutiqueAbstract({required int id, required String name, required DateTime? updateDate, required DateTime creationDate, required bool status, required DateTime? statusUpdateDate, required double promo, Phone phone = Phone.empty, String mail = '', AddressWeebi addressFull = AddressWeebi.empty})

Properties

addressFull → AddressWeebi
final
creationDate → DateTime
final
hashCode → int
The hash code for this object.
no setteroverride
id → int
final
mail → String
final
name → String
final
phone → Phone
final
promo → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → bool
final
statusUpdateDate → DateTime?
final
updateDate → DateTime?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override