ContactAbstract class abstract

Implementers

Constructors

ContactAbstract({required int id, required String firstName, required String lastName, Phone phone = const Phone(0, ''), String mail = '', String avatar = '', int overdraft = 0, bool status = true, DateTime? updateDate, DateTime? statusUpdateDate})
const

Properties

avatar → String
final
firstName → String
final
hashCode → int
The hash code for this object.
no setteroverride
id → int
final
lastName → String
final
mail → String
final
overdraft → int
final
phone → Phone
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → bool
final
statusUpdateDate → DateTime?
final
updateDate → DateTime?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override