PhotoObject class

Inheritance

Constructors

PhotoObject({required String path, required PhotoSource source})
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
path → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → PhotoSource
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant PhotoObject other) → bool
The equality operator.
override