ProxyArticleAbstract class abstract

Implementers

Constructors

ProxyArticleAbstract({required int calibreId, required int articleId, required int id, required int proxyCalibreId, required int proxyArticleId, bool status = true})
const

Properties

articleId → int
final
calibreId → int
final
hashCode → int
The hash code for this object.
no setteroverride
id → int
final
productId → int
no setter
proxyArticleId → int
final
proxyCalibreId → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → bool
final
text → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override