TaxAbstract class abstract

Implementers

Constructors

TaxAbstract({required String id, required String name, required double percentage})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String
final
name → String
final
percentage → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited