TicketRawAbstract<I extends ItemAbstract<ArticleRawAbstract>, T extends TaxAbstract> class abstract

Implementers
Available extensions

Constructors

TicketRawAbstract({required int id, required List<I> items, required T taxe, double promo = 0.0, String comment = '', required num received, required DateTime date, required int contactId, required PaymentType paymentType, required TicketType ticketType, required bool status, required DateTime? statusUpdateDate, required DateTime creationDate})
const

Properties

comment → String
final
contactId → int
final
creationDate → DateTime
final
date → DateTime
final
hashCode → int
The hash code for this object.
no setteroverride
id → int
final
items → List<I>
final
paymentType → PaymentType
final
promo → double
final
received → num
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → bool
final
statusUpdateDate → DateTime?
final
taxe → T
final
ticketType → TicketType
final

Methods

incrementClosingStockBoutique(List<ClosingStockBoutiqueCalibre> stockBoutiqueArtCalibres) → void

Available on T, provided by the ArtCalibreClosingBoyFeelsGoodAfterGulpingTBoneSteak extension

incrementMyClosingStockPlease(List<ClosingStockCalibre> stockArtCalibres) → void

Available on T, provided by the ArtCalibreClosingBoyFeelsGoodAfterGulpingTBoneSteak extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({required bool isProto}) → String
toMap({required bool isProto}) → Map<String, dynamic>
isProto is used for server pull/push, too sensitive to keep it optional
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override