ClosingRange class

Inheritance
Available extensions

Constructors

ClosingRange({required DateTime date, required DateTime start, required DateTime end})
ClosingRange.fromJson(String source)
factory
ClosingRange.fromMap(Map<String, dynamic> map)
factory

Properties

date → DateTime
final
duration → Duration

Available on DateRange, provided by the DateRangeExt extension

no setter
end → DateTime
finalinherited
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → DateTime
finalinherited

Methods

copyWith({DateTime? date, DateTime? start, DateTime? end}) → ClosingRange
copyWith({DateTime? start, DateTime? end}) → DateRange

Available on DateRange, provided by the DateRangeExt extension

isInRange(DateTime startDateRange, DateTime endDateRange) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override