ClosingStock<C extends ClosingStockCalibre> class

Implemented types
Implementers

Constructors

ClosingStock(ClosingRange closingRange, {required List<C> articleCalibres})
const
ClosingStock.fromJson(String source)
factory
ClosingStock.fromMap(Map<String, dynamic> map)
factory

Properties

articleCalibres → List<C>
final
closingRange → ClosingRange
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Properties

dummy → ClosingStock<ClosingStockCalibre>
final