FinancialSums class abstract

Implementers

Constructors

FinancialSums(num sell, num sellCovered, num sellDeferred, num spend, num spendCovered, num spendDeferred, num wage)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sell → num
final
sellCovered → num
final
sellDeferred → num
final
spend → num
final
spendCovered → num
final
spendDeferred → num
final
wage → num
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited