EnvironmentWeebi class

Inheritance

Constructors

EnvironmentWeebi(String _env)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
isNotProd → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
tryParse(String val) → EnvironmentWeebi
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

dev → const EnvironmentWeebi
ldb → const EnvironmentWeebi
local → const EnvironmentWeebi
normal → const EnvironmentWeebi
unknown → const EnvironmentWeebi