ServiceArticleAbstract class abstract

Inheritance

Constructors

ServiceArticleAbstract({required Object getCalibresRpc, required Object addAllCalibresRpc, required Object updateLineRpc, required Object deleteForeverLineRpc, required Object updateArticleRpc, required Object createLineArticleRpc, required Object createArticleRpc, required Object deleteAllCalibresRpc})

Properties

addAllCalibresRpc → Object
final
addAllRpc → Object
finalinherited
addRpc → Object
finalinherited
createArticleRpc → Object
final
createLineArticleRpc → Object
final
deleteAllCalibresRpc → Object
final
deleteAllRpc → Object
finalinherited
deleteForeverLineRpc → Object
final
deleteRpc → Object
finalinherited
getAllRpc → Object
finalinherited
getCalibresRpc → Object
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateArticleRpc → Object
final
updateLineRpc → Object
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited