ServiceTicketAbstract class abstract

Constructors

ServiceTicketAbstract({required Object addTicketRpc, required Object disableTicketRpc, required Object getAllTicketsRpc, required Object restoreTicketRpc, required Object addAllTicketsRpc, required Object deleteTicketRpc, required Object deleteAllTicketsRpc})
const

Properties

addAllTicketsRpc → Object
final
addTicketRpc → Object
final
deleteAllTicketsRpc → Object
final
deleteTicketRpc → Object
final
disableTicketRpc → Object
final
getAllTicketsRpc → Object
final
hashCode → int
The hash code for this object.
no setterinherited
restoreTicketRpc → Object
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited