AddressWeebi class

Constructors

AddressWeebi({required String street, required String city, String code = '', required Country country, double latitude = 0.0, double longitude = 0.0})
const
AddressWeebi.fromJson(String source)
factory
AddressWeebi.fromMap(Map<String, dynamic> map)
factory

Properties

city → String
final
code → String
final
country → Country
final
hashCode → int
The hash code for this object.
no setteroverride
latitude → double
final
longitude → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
street → String
final

Methods

copyWith({String? street, String? code, String? city, Country? country, double? latitude, double? longitude}) → AddressWeebi
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, Object>
toString() → String
A string representation of this object.
override
toStringWithCountry() → String

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

empty → const AddressWeebi