Phone class

Constructors

Phone(int countryCode, String number)
const
Phone.fromJson(String source)
factory
Phone.fromMap(Map<String, dynamic> map)
factory

Properties

countryCode → int
final
hashCode → int
The hash code for this object.
no setteroverride
number → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? countryCode, String? number}) → Phone
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

empty → const Phone