PhotoSource class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

tryParse(String? val) → PhotoSource

Constants

asset → const PhotoSource
file → const PhotoSource
memory → const PhotoSource
network → const PhotoSource
unknown → const PhotoSource