ImportData extension

on

Properties

extractArticlesPhotosFromParsedExcel → List<ArticlePhoto>

Available on List<List>, provided by the ImportData extension

no setter

Methods

extractArticlesCalibresFromParsedCsvExcel(int nextLineId) → List<CalibreWeebi<ArticleRetail>>

Available on List<List>, provided by the ImportData extension

extractCalibresOfArticlesForUpdateFromParsedCsvExcel() → List<CalibreWeebi<ArticleRetail>>

Available on List<List>, provided by the ImportData extension

extractContactsForUpdateFromParsedCsvExcel() → List<ContactWeebi>

Available on List<List>, provided by the ImportData extension

bulk imports cannot deduce country dial code, avoid adding another column or a dodgy logic, nobody cares similiarly they cannot deduce check country code solidly enough
extractContactsFromParsedCsvExcel(int nextContactId) → List<ContactWeebi>

Available on List<List>, provided by the ImportData extension

bulk imports cannot deduce country dial code, avoid adding another column or a dodgy logic, nobody cares similiarly they cannot deduce check country code solidly enough