TicketsGroupedByTimeFrame class

Constructors

TicketsGroupedByTimeFrame(dynamic timeFrame, Set<TicketWeebi> tickets)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tickets → Set<TicketWeebi>
final
timeFrame → dynamic
final
total → num
no setter
totalSellDeferredTaxAndPromoExcluded → num
no setter
totalSellTaxAndPromoExcluded → num
no setter
totalSpendDeferredTaxAndPromoExcluded → num
no setter
totalSpendTaxAndPromoExcluded → num
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited