ArticleBasket class

Inheritance

Constructors

ArticleBasket({required int calibreId, required int id, required String designation, required List<ProxyArticle> proxies, ArticleKind kind = ArticleKind.basket, required DateTime creationDate, DateTime? updateDate, DateTime? statusUpdateDate, bool status = true, num discountAmountSalesOnly = 0, num markupAmountSalesOnly = 0})
ArticleBasket.fromJson(String source)
factory
ArticleBasket.fromMap(Map<String, dynamic> map)
factory

Properties

articleBasketOnTicket → ArticleBasketOnTicket
no setter
calibreId → int
finalinherited
creationDate → DateTime
final
designation → String
finalinherited
discountAmountSalesOnly → num
final
hashCode → int
The hash code for this object.
no setteroverride
id → int
finalinherited
kind → ArticleKind
finalinherited
markupAmountSalesOnly → num
final
proxies → List<ProxyArticle>
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → bool
finalinherited
statusUpdateDate → DateTime?
final
updateDate → DateTime?
final

Methods

copyWith({int? calibreId, int? id, String? designation, int? articleCode, num? discountAmountSalesOnly, num? markupAmountSalesOnly, DateTime? creationDate, DateTime? updateDate, bool? status, List<ProxyArticle>? proxies, DateTime? statusUpdateDate}) → ArticleBasket
getProxiesListWithPriceAndCost(Iterable<CalibreWeebi<ArticleRawAbstract>> calibres) → Iterable<ProxyArticleWorth>
getProxiesListWithPriceAndCostArticleNotCreatedYetOnly(Iterable<CalibreWeebi<ArticleRawAbstract>> calibres) → Iterable<ProxyArticleWorth>
nameWithoutArtCalibrePart(String calibreTitle) → String
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
override
toMap() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Properties

dummy → ArticleBasket
no setter