ArticleBasketOnTicket class

Inheritance

Constructors

ArticleBasketOnTicket({required int calibreId, required int id, ArticleKind kind = ArticleKind.basket, required String designation, bool status = true, required List<ProxyArticle> proxies, num discountAmountSalesOnly = 0, num markupAmountSalesOnly = 0})
ArticleBasketOnTicket.fromJson(String source)
factory
ArticleBasketOnTicket.fromMap(Map<String, dynamic> map)
factory

Properties

calibreId → int
finalinherited
designation → String
finalinherited
discountAmountSalesOnly → num
final
hashCode → int
The hash code for this object.
no setteroverride
id → int
finalinherited
kind → ArticleKind
finalinherited
markupAmountSalesOnly → num
final
proxies → List<ProxyArticle>
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → bool
finalinherited

Methods

copyWith({int? calibreId, int? id, String? designation, num? discountAmountSalesOnly, num? markupAmountSalesOnly, List<ProxyArticle>? proxies}) → ArticleBasketOnTicket
getProxiesListWithPriceAndCost(Iterable<CalibreWeebi<ArticleRawAbstract>> calibres) → Iterable<ProxyArticleWorth>
getProxiesListWithPriceAndCostArticleNotCreatedYetOnly(Iterable<CalibreWeebi<ArticleRawAbstract>> calibres) → Iterable<ProxyArticleWorth>
nameWithoutArtCalibrePart(String calibreTitle) → String
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
override
toMap() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Properties

dummyBasketOnTicket → ArticleBasketOnTicket
final