ArticlePhoto class

Inheritance

Constructors

ArticlePhoto({required int calibreId, required int id, required String path, required PhotoSource source, DateTime? dateUTC})
const
ArticlePhoto.fromJson(String source)
factory
ArticlePhoto.fromMap(Map<String, dynamic> map)
factory

Properties

calibreId → int
finalinherited
dateUTC → DateTime?
will be compared against a date in UTC for server, simpler to store is as UTC
finalinherited
hashCode → int
The hash code for this object.
no setteroverride
id → int
finalinherited
path → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → PhotoSource
finalinherited

Methods

copyWith({int? calibreId, int? id, String? path, PhotoSource? source, DateTime? dateUTC}) → ArticlePhoto
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
override
toMap() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Properties

dummy → ArticlePhoto
final