ArticleUncountable class

An ArticleUncountable is an item bought/sold out of the catalog usually because it is uncountable for quick spending (e.g. transport fee, electricity bill) or for quick selling exceptionnal stuff (e.g. payment for a service, a loan)

Since weebi persists the ArticleUncountable for quickspend for convenience (these are tracked with negative id, like shadow articles) And even though users might use them for countable stuff I prefer the term Uncountable which is less confusing than out of catalog

Inheritance

Constructors

ArticleUncountable({required int calibreId, required int id, required String designation, ArticleKind kind = ArticleKind.uncountable, required num price, required num cost, required DateTime creationDate, DateTime? updateDate, DateTime? statusUpdateDate, bool status = true})
ArticleUncountable.fromJson(String source)
factory
ArticleUncountable.fromMap(Map<String, dynamic> map)
factory

Properties

calibreId → int
finalinherited
cost → num
finalinherited
costClean → num
no setterinherited
creationDate → DateTime
final
designation → String
finalinherited
hashCode → int
The hash code for this object.
no setteroverride
id → int
finalinherited
kind → ArticleKind
finalinherited
lightOnTicket → ArticleUncountableOnTicket
no setter
price → num
finalinherited
priceClean → num
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → bool
finalinherited
statusUpdateDate → DateTime?
final
updateDate → DateTime?
final

Methods

copyWith({int? calibreId, int? id, String? designation, DateTime? creationDate, DateTime? updateDate, num? price, num? cost, DateTime? statusUpdateDate, bool? status}) → ArticleUncountable
nameWithoutArtCalibrePart(String calibreTitle) → String
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
override
toMap() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Properties

dummy → ArticleUncountable
final