ArticleWMinQt class

Used only by articlebasket to know how the minimum Qt (ex : 1 piece) of an article (retail) should go in the basket

Inheritance

Constructors

ArticleWMinQt(double minQt, {required int calibreId, required int id, required String designation, required double unitsInOnePiece, required num price, required num cost})

Properties

calibreId → int
finalinherited
cost → num
finalinherited
costClean → num
no setterinherited
designation → String
finalinherited
hashCode → int
The hash code for this object.
no setteroverride
id → int
finalinherited
kind → ArticleKind
finalinherited
minQt ↔ double
getter/setter pair
price → num
finalinherited
priceClean → num
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → bool
finalinherited
unitsInOnePiece → double
finalinherited

Methods

nameWithoutArtCalibrePart(String calibreTitle) → String
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
inherited
toMap() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Properties

dummy → dynamic
no setter