BasketWrapper class

Constructors

BasketWrapper(ArticleRetail article, double minimumUnitPerBasket, double stockRemaining)
const

Properties

article → ArticleRetail
final
hashCode → int
The hash code for this object.
no setterinherited
minimumUnitPerBasket → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stockRemaining → double
final

Methods

copyWith({ArticleRetail? article, double? minimumUnitPerBasket, double? stockRemaining}) → BasketWrapper
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited