ContactWeebi class

Inheritance

Constructors

ContactWeebi({required int id, required String firstName, required String lastName, required DateTime creationDate, DateTime? updateDate, DateTime? statusUpdateDate, bool status = true, required AddressWeebi? addressFull, Phone phone = const Phone(0, ''), String mail = '', String avatar = '', int overdraft = 0, bool isClient = false, bool isSupplier = false, List<String> categories = const <String>[]})
ContactWeebi.fromJson(String source)
factory
ContactWeebi.fromMap(Map<String, dynamic> map)
factory

Properties

addressFull → AddressWeebi?
final
avatar → String
finalinherited
categories → List<String>
final
creationDate → DateTime
final
firstName → String
finalinherited
fullName → String
no setter
fullNameHash → int
no setter
hashCode → int
The hash code for this object.
no setteroverride
id → int
finalinherited
isClient → bool
final
isSupplier → bool
final
lastName → String
finalinherited
mail → String
finalinherited
mailHash → int
no setter
overdraft → int
finalinherited
phone → Phone
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sharableText → String
no setter
status → bool
finalinherited
statusUpdateDate → DateTime?
finalinherited
telHash → int
no setter
updateDate → DateTime?
finalinherited

Methods

copyWith({int? id, String? firstName, String? lastName, Phone? phone, String? mail, AddressWeebi? addressFull, DateTime? creationDate, DateTime? updateDate, DateTime? statusUpdateDate, bool? status, Tristate? isWomanTri, bool? isClient, bool? isSupplier, List<String>? categories, String? avatar, int? overdraft}) → ContactWeebi
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
override
toMap() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Properties

defaultContact → ContactWeebi
final
dummy → ContactWeebi
final
dummy2 → ContactWeebi
final