DeviceCloudIdentity class

Constructors

DeviceCloudIdentity(String firmId, String chainId, String boutiqueId, String deviceId, bool isFirstSync)
const
DeviceCloudIdentity.fromJson(String source)
factory
DeviceCloudIdentity.fromMap(Map<String, dynamic> map)
factory

Properties

boutiqueId → String
final
chainId → String
final
deviceId → String
final
firmId → String
final
hashCode → int
The hash code for this object.
no setteroverride
isCloudLinked → bool
no setter
isFirstSync → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? firmId, String? chainId, String? boutiqueId, String? deviceId, bool? isFirstSync}) → DeviceCloudIdentity
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

empty → const DeviceCloudIdentity