FinFlow class

Constructors

FinFlow(String type, {required num sumTickets, num sumClosings = 0})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sumClosings ↔ num
getter/setter pair
sumTickets ↔ num
getter/setter pair
sumTotal → num
no setter
type → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

emptyFinancials → List<FinFlow>
final

Constants

balance → const String
balanceCumulated → const String
cvo → const String