ItemCartWeebi<A extends ArticleRawAbstract> class

Constructors

ItemCartWeebi(ArticleCreator<A> articleCreator, double quantity, {List<ProxyArticleWorth>? proxiesWorth, double? inventoryAbsoluteQt})
ItemCartWeebi.fromJson(String source, {required bool isProto})
factory

Properties

article → A
finalinherited
articleCost → num
no setter
articleCostString → String
no setter
articleCreator ↔ ArticleCreator<A>
getter/setter pairinherited
articlePrice → num
no setter
articlePriceString → String
instead of printing 10000 print 10K
no setter
hashCode → int
The hash code for this object.
no setter
inventoryAbsoluteQt → double?
used only when using the inventory functionnality
final
isBasket → bool
no setter
isUncountable → bool
no setter
proxiesWorth → List<ProxyArticleWorth>?
finalinherited
quantity ↔ double
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalCost → num
no setter
totalCostString → String
no setter
totalPrice → num
no setter
totalPriceString → String
instead of printing 1000000 print 1 000 000
no setter

Methods

copyWith({ArticleCreator<A>? articleCreator, double? quantity, List<ProxyArticleWorth>? proxiesWorth, double? inventoryAbsoluteQt}) → ItemCartWeebi<ArticleRawAbstract>
getStockMovementForArticle<AA extends ArticleRawAbstract>(AA aSelected) → double
getStockMovementForCalibre(CalibreWeebi<ArticleRawAbstract> calibre) → double
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({required bool isProto}) → String
toMap({required bool isProto}) → Map<String, dynamic>
isProto is only true for server pull/push, too sensitive to be optional
toString() → String
A string representation of this object.

Operators

operator ==(Object other) → bool
The equality operator.

Static Methods

fromMap(Map<String, dynamic> map, {required bool isProto}) → dynamic