ProxyArticle class

Inheritance
Mixed-in types
Implementers

Constructors

ProxyArticle({required int calibreId, required int articleId, required int id, required int proxyCalibreId, required int proxyArticleId, required double minimumUnitPerBasket, required double articleWeight, bool status = true})
ProxyArticle.fromJson(String source)
factory
ProxyArticle.fromMap(Map<String, dynamic> map)
factory

Properties

articleId → int
finalinherited
articleWeight → double
final
calibreId → int
finalinherited
hashCode → int
The hash code for this object.
no setteroverride
id → int
finalinherited
minimumUnitPerBasket → double
final
productId → int
no setterinherited
proxyArticleId → int
finalinherited
proxyCalibreId → int
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → bool
finalinherited
text → String
no setterinherited
unitsInOnePiece → double
no setter

Methods

copyWith({int? calibreId, int? articleId, int? id, int? proxyCalibreId, int? proxyArticleId, bool? status, double? minimumUnitPerBasket, double? articleWeight}) → ProxyArticle
getCost(Iterable<CalibreWeebi<ArticleRawAbstract>> linesInStore) → num
getPrice(Iterable<CalibreWeebi<ArticleRawAbstract>> linesInStore) → num
getProxyArticleWorth(Iterable<CalibreWeebi<ArticleRawAbstract>> linesInStore) → ProxyArticleWorth
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
override
toMap() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Properties

dummy → ProxyArticle
final