SessionContextTest class

Simple test implementation of SessionContext Use this for testing stores without needing full Gatekeeper setup

Implemented types

Constructors

SessionContextTest({bool isLinked = false, String firmId = '', String chainId = '', String deviceId = '', String boutiqueId = '', String userId = ''})
const
SessionContextTest.linked({String firmId = 'test-firm', String chainId = 'test-chain', String deviceId = 'test-device', String boutiqueId = 'test-boutique', String userId = 'test-user'})
Creates a SessionContext with device linked
factory
SessionContextTest.notLinked()
Creates a SessionContext with device not linked
factory

Properties

boutiqueId → String
Boutique ID (point of sale identifier)
final
chainId → String
Chain ID (from device enrollment)
final
deviceId → String
Device ID (unique device identifier)
final
firmId → String
Current firm ID (from user's JWT token)
final
hashCode → int
The hash code for this object.
no setterinherited
isLinked → bool
Whether the device is linked/enrolled to the cloud
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId → String
Current user ID (from JWT token)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited