TicketType class

Available extensions

Properties

hashCode → int
The hash code for this object.
no setterinherited
isBoutiqueInput → bool
no setter
isBoutiqueOutput → bool
no setter
isContactInput → bool
no setter
isCost → bool
no setter
isCost → bool

Available on TicketType, provided by the PriceCostGetter extension

no setter
isFinancial → bool
no setter
isPrice → bool
no setter
isPrice → bool

Available on TicketType, provided by the PriceCostGetter extension

no setter
isWithCustomer → bool
no setter
isWithSupplier → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

allTicketTypes ↔ List<TicketType>
getter/setter pair

Static Methods

tryParse(String? val) → TicketType

Constants

financialTypes → const List<TicketType>
inventory → const TicketType
sell → const TicketType
sellCovered → const TicketType
sellDeferred → const TicketType
spend → const TicketType
spendCovered → const TicketType
spendDeferred → const TicketType
stockIn → const TicketType
stockOut → const TicketType
stockTypes → const List<TicketType>
unknown → const TicketType
wage → const TicketType