CellTotal class

Constructors

CellTotal(DateRange dateRange, TicketType ticketType, double total)
const

Properties

dateRange → DateRange
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
ticketType → TicketType
final
total → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited