ComputeStockContact mixin

Superclass constraints
Mixin applications
Available extensions

Properties

articlesC → List<CalibreWeebi<ArticleRawAbstract>>
finalinherited
closingsObjects → List<ClosingStockContact>
finalinherited
duration → Duration

Available on DateRange, provided by the DateRangeExt extension

no setter
emptyReportStockArtCalibres ↔ List<ReportStockArtCalibre>
getter/setter pairinherited
end → DateTime
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
objectId → int
finalinherited
reportStockArtCalibres → List<ReportStockArtCalibre>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → DateTime
finalinherited
tickets → List<TicketWeebi>
finalinherited

Methods

copyWith({DateTime? start, DateTime? end}) → DateRange

Available on DateRange, provided by the DateRangeExt extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited