ReportFinancial<C extends ClosingRangeAbstract> class abstract

Inheritance
Implementers
Available extensions

Constructors

ReportFinancial({required List<TicketWeebi> tickets, required List<C> closingsObjects, required DateTime startDate, required DateTime endDate, required int objectId})

Properties

closingsObjects → List<C>
finalinherited
duration → Duration

Available on DateRange, provided by the DateRangeExt extension

no setter
emptyFlows ↔ List<FinFlow>
getter/setter pair
end → DateTime
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
objectId → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → DateTime
finalinherited
tickets → List<TicketWeebi>
finalinherited

Methods

copyWith({DateTime? start, DateTime? end}) → DateRange

Available on DateRange, provided by the DateRangeExt extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited