ReportStockArtCalibre class

Inheritance
Implemented types
Available extensions

Constructors

ReportStockArtCalibre({required int id, required String title, required DateTime start, required DateTime end, required double initialQtCl, required double finalQtCl, required double varQtTickets, List<ReportStockArticle>? articles})

Properties

articles → List<ReportStockArticle>
finalinherited
creationDate → DateTime
finalinherited
duration → Duration

Available on DateRange, provided by the DateRangeExt extension

no setter
end ↔ DateTime
getter/setter pairoverride-getter
finalQtCl ↔ double
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasSingleArticle → bool
no setterinherited
id → int
finalinherited
initialQtCl ↔ double
getter/setter pair
kind → ArticleKind
finalinherited
qtVariationDuringATimeRangeSuper → double
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start ↔ DateTime
getter/setter pairoverride-getter
status → bool
finalinherited
statusUpdateDate → DateTime?
finalinherited
stockUnit → StockUnit
finalinherited
title → String
finalinherited
updateDate → DateTime?
finalinherited
varQtTickets ↔ double
getter/setter pair

Methods

copyWith({DateTime? start, DateTime? end}) → DateRange

Available on DateRange, provided by the DateRangeExt extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({required bool isProto}) → String
inherited
toMap({required bool isProto}) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited