ReportStockContact class

Inheritance
Mixed-in types
Available extensions

Constructors

ReportStockContact({required ContactWeebi herder, required List<ClosingStockContact> closingContactStocks, required List<TicketWeebi> tickets, required List<CalibreWeebi<ArticleRawAbstract>> articlesC, required DateTime startDate, required DateTime endDate})

Properties

articlesC → List<CalibreWeebi<ArticleRawAbstract>>
finalinherited
closingsObjects → List<ClosingStockContact>
finalinherited
duration → Duration

Available on DateRange, provided by the DateRangeExt extension

no setter
emptyReportStockArtCalibres ↔ List<ReportStockArtCalibre>
getter/setter pairinherited
end → DateTime
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
herder → ContactWeebi
final
objectId → int
finalinherited
reportStockArtCalibres → List<ReportStockArtCalibre>
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → DateTime
finalinherited
tickets → List<TicketWeebi>
finalinherited

Methods

copyWith({DateTime? start, DateTime? end}) → DateRange

Available on DateRange, provided by the DateRangeExt extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited