DateRange class

Implementers
Available extensions

Constructors

DateRange(DateTime start, DateTime end)

Properties

duration → Duration

Available on DateRange, provided by the DateRangeExt extension

no setter
end → DateTime
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → DateTime
final

Methods

copyWith({DateTime? start, DateTime? end}) → DateRange

Available on DateRange, provided by the DateRangeExt extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Properties

defaultDateRange → DateRange
final