DateRangesWithTimeSpan class

Constructors

DateRangesWithTimeSpan(Timespan timespan, List<DateRange> ranges)
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
ranges → List<DateRange>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timespan → Timespan
final

Methods

copyWith({Timespan? timespan, List<DateRange>? ranges}) → DateRangesWithTimeSpan
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override