DatesWeebi class abstract

Constructors

DatesWeebi()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

defaultDate → DateTime
final
defaultFirstDate → DateTime
final
defaultLastDate → DateTime
final
febEnd → DateTime
final
febStart → DateTime
final
marEnd → DateTime
final
marStart → DateTime
final
octEnd → DateTime
final
octStart → DateTime
final
sunday19Nov2023 → DateTime
final