BusinessRules class
Constructors
- BusinessRules({required bool isNegativeStockGuardEnabled, required bool isRecentTicketEditEnabled, required int recentTicketEditWindowMinutes})
-
const
-
BusinessRules.fromMap(Map<
String, dynamic> map) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNegativeStockGuardEnabled → bool
-
Guard against negative stocks in the chain when true
final
- isRecentTicketEditEnabled → bool
-
Allow recent ticket edit in the chain when true
final
- recentTicketEditWindowMinutes → int
-
Time window (in minutes) for allowing recent ticket edits
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{bool? isNegativeStockGuardEnabled, bool? isRecentTicketEditEnabled, int? recentTicketEditWindowMinutes}) → BusinessRules -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaults → const BusinessRules