TicketWeebi class

Inheritance
Available extensions

Constructors

TicketWeebi({required int id, required List<ItemCartWeebi<ArticleRawAbstract>> items, required TaxWeebi taxe, required double promo, required String comment, required num received, required DateTime date, required PaymentType paymentType, required TicketType ticketType, required int contactId, String contactFirstName = '', String contactLastName = '', String contactPhone = '', String contactMail = '', String currency = '', String snapshotSecondaryCurrency = '', double snapshotLocalPerSecondary = 0.0, bool status = true, required DateTime? statusUpdateDate, required DateTime creationDate, num discountAmount = 0})
TicketWeebi.fromJson(String source, {required bool isProto})
factory
TicketWeebi.fromMap(Map<String, dynamic> map, {required bool isProto})
factory

Properties

comment String
finalinherited
contactFirstName String
final
contactId int
finalinherited
contactIdString String
no setter
contactLastName String
final
contactMail String
final
contactPhone String
final
creationDate DateTime
finalinherited
currency String
ISO 4217 currency code (e.g. USD).
final
date DateTime
finalinherited
deactivatedDate String
no setterinherited
discountAmount num
finalinherited
hashCode int
The hash code for this object.
no setteroverride
id int
finalinherited
items List<ItemCartWeebi<ArticleRawAbstract>>
finalinherited
numChange num?
no setterinherited
numMarkdowns num?
no setterinherited
numPromo num?
no setterinherited
numTotalTaxAndMarkdownsExcluded num?
no setterinherited
numTotalTaxAndMarkdownsIncluded num?
no setterinherited
numTotalTaxes num?
no setterinherited
numTotalTaxExcludedIncludingMarkdowns num?
no setterinherited
paymentType PaymentType
finalinherited
promo double
finalinherited
received num
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sellFull num
no setterinherited
snapshotLocalPerSecondary double
Units of local (boutique) currency for one unit of snapshotSecondaryCurrency.
final
snapshotSecondaryCurrency String
Snapshot FX fields captured at ticket creation time (cashier provided). Empty secondary currency means "no FX snapshot".
final
spendFull num
no setterinherited
status bool
getter/setter pairinherited
statusUpdateDate DateTime?
finalinherited
taxe TaxWeebi
finalinherited
ticketType TicketType
finalinherited
total num
no setterinherited
totalCostItemsOnly num
no setterinherited
totalCostPromoVal num
no setterinherited
totalCostTaxAndMarkdownsIncluded num
no setterinherited
totalCostTaxesVal num
no setterinherited
totalCostTaxExcludedIncludingMarkdowns num
no setterinherited
totalPriceItemsOnly num
no setterinherited
totalPricePromoVal num
no setterinherited
totalPriceTaxAndMarkdownsIncluded num
no setterinherited
totalPriceTaxesVal num
no setterinherited
totalPriceTaxExcludedMarkdownsIncluded num
no setterinherited
uniqueId String
restrain from using microsecondsSinceEpoch, it seems be more precise, but does not always fit into 53 bits
no setter

Methods

calculateSumsOfTicket(TicketType ticketType, DateTime startOfMonth, DateTime endOfMonth) num
inherited
copyWith({String? firmIdAndBoutiqueId, int? id, int? shopId, List<ItemCartWeebi<ArticleRawAbstract>>? items, TaxWeebi? taxe, double? promo, num? discountAmount, String? comment, num? received, DateTime? date, PaymentType? paymentType, TicketType? ticketType, int? contactId, String? contactFirstName, String? contactLastName, String? contactPhone, String? contactMail, String? currency, String? snapshotSecondaryCurrency, double? snapshotLocalPerSecondary, bool? status, DateTime? statusUpdateDate, DateTime? creationDate}) TicketWeebi
incrementClosingStockBoutique(List<ClosingStockBoutiqueCalibre> clStockBoutiqueArtCalibres) → void

Available on TicketWeebi, provided by the ArtCalibreClosingBoyFeelsGoodAfterGulpingTBoneSteak extension

incrementMyClosingStock(List<ClosingStockCalibre> stockCalibres) → void

Available on TicketWeebi, provided by the ArtCalibreClosingBoyFeelsGoodAfterGulpingTBoneSteak extension

incrementMyClosingStockContact(List<ClosingStockCalibre> stockCalibres) → void

Available on TicketWeebi, provided by the ArtCalibreClosingBoyFeelsGoodAfterGulpingTBoneSteak extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
promoVal(num itemsTotal, double promo) num
inherited
soldQtByArticle(String articleName, DateTime startOfMonth, DateTime endOfMonth) double
inherited
taxesVal(num itemsTotal, double promo, num discountAmount, double taxePercentage) num
inherited
toJson({required bool isProto}) String
override
toMap({required bool isProto}) Map<String, dynamic>
pass isProto whenever pushing/pulling to/from the server
override
toString() String
items.toMap(isProto: false) to keep it clean
override
totalTaxAndMarkdownsIncluded(num itemsTotal, double promo, num discountAmount, double taxePercentage) num
inherited
totalTaxExcludedMarkdownsIncluded(num itemsTotal, double promo, num discountAmount) num
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Properties

dummySell TicketWeebi
final
dummySpend TicketWeebi
final